#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 status-notifier-item
version:              0.3.2.1
visibility:           public
id:                   status-notifier-item-0.3.2.1-7ox1wBQsulbLukSipKb7sC
key:                  status-notifier-item-0.3.2.1-7ox1wBQsulbLukSipKb7sC
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  6a020a51607b94bd94ca33ab5284ebaa
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.2.1-7ox1wBQsulbLukSipKb7sC
depends:
    base-4.18.2.1 byte-order-0.1.3.1-EKAAQXfzpKD435VswGV0rV
    bytestring-0.11.5.3
    bytestring-to-vector-0.3.0.1-DL0iSqUX4pG14ERNYKIFQD
    containers-0.6.7 dbus-1.3.3-Bizb6bRYqXmGffe1GYITKs
    filepath-1.4.300.1 hslogger-1.3.2.0-Kv8fCBI2PkQF3wi9Tfkxar
    lens-5.3.5-7MUa280kiW5NfytVlUfpR template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    vector-0.13.2.0-pkGAkHyCfVA94J1hIBHJi

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

